from .ondoc_object import OnDoc
from .standard_object import StandardOcr

__all__ = (
    "OnDoc",
    "StandardOcr",
)
